CodeMirror: Hard-wrapping Demo

## Hard-wrapping Demo

Lorem ipsum dolor sit amet, vim augue dictas constituto ex, sit falli simul viderer te. Graeco scaevola maluisset sit ut, in idque viris praesent sea. Ea sea eirmod indoctum repudiare. Vel noluisse suscipit pericula ut. In ius nulla alienum molestie. Mei essent discere democritum id. Equidem ponderum expetendis ius in, mea an erroribus constituto, congue timeam perfecto ad est. Ius ut primis timeam, per in ullum mediocrem. An case vero labitur pri, vel dicit laoreet et. An qui prompta conclusionemque, eam timeam sapientem in, cum dictas epicurei eu. Usu cu vide dictas deseruisse, eum choro graece adipiscing ut. Cibo qualisque ius ad, et dicat scripta mea, eam nihil mentitum aliquando cu. Debet aperiam splendide at quo, ad paulo nostro commodo duo. Sea adhuc utinam conclusionemque id, quas doming malorum nec ad. Tollit eruditi vivendum ad ius, eos soleat ignota ad.

Demonstration of the hardwrap addon. The above editor has its change event hooked up to the `wrapParagraphsInRange` method, so that the paragraphs are reflown as you are typing.